@@ -27,7 +27,7 @@
 #   Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 #   Boston, MA 02111-1307, USA.
 #
-#   $Id: Lite.pm,v 1.5 2004/05/21 15:04:43 fredo Exp $
+#   $Id: Lite.pm,v 1.6 2004/06/07 19:44:12 fredo Exp $
 #
 #=======================================================================
 
@@ -43,7 +43,7 @@ BEGIN {
 
     use vars qw( $VERSION $hasWeakRef );
 
-    ( $VERSION ) = '$Revision: 1.5 $' =~ /Revision: (\S+)\s/; # $Date: 2004/05/21 15:04:43 $
+    ( $VERSION ) = '$Revision: 1.6 $' =~ /Revision: (\S+)\s/; # $Date: 2004/06/07 19:44:12 $
 
 }
 
@@ -667,6 +667,9 @@ alfred reibenschuh
 =head1 HISTORY
 
     $Log: Lite.pm,v $
+    Revision 1.6  2004/06/07 19:44:12  fredo
+    cleaned out cr+lf for lf
+
     Revision 1.5  2004/05/21 15:04:43  fredo
     fixed NAME pod bug for cpan indexer
 
