@@ -27,7 +27,7 @@
 #   Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 #   Boston, MA 02111-1307, USA.
 #
-#   $Id: CIDFont.pm,v 1.4 2003/12/08 13:05:33 Administrator Exp $
+#   $Id: CIDFont.pm,v 1.5 2004/06/07 19:44:36 fredo Exp $
 #
 #=======================================================================
 package PDF::API2::Resource::CIDFont;
@@ -48,7 +48,7 @@ BEGIN {
 
     @ISA = qw( PDF::API2::Resource::BaseFont );
 
-    ( $VERSION ) = '$Revision: 1.4 $' =~ /Revision: (\S+)\s/; # $Date: 2003/12/08 13:05:33 $
+    ( $VERSION ) = '$Revision: 1.5 $' =~ /Revision: (\S+)\s/; # $Date: 2004/06/07 19:44:36 $
 
 }
 
@@ -246,6 +246,9 @@ alfred reibenschuh
 =head1 HISTORY
 
     $Log: CIDFont.pm,v $
+    Revision 1.5  2004/06/07 19:44:36  fredo
+    cleaned out cr+lf for lf
+
     Revision 1.4  2003/12/08 13:05:33  Administrator
     corrected to proper licencing statement
 
