@@ -27,7 +27,7 @@
 #   Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 #   Boston, MA 02111-1307, USA.
 #
-#   $Id: FontFile.pm,v 1.4 2004/04/20 09:46:25 fredo Exp $
+#   $Id: FontFile.pm,v 1.5 2004/06/07 19:44:43 fredo Exp $
 #
 #=======================================================================
 package PDF::API2::Resource::CIDFont::TrueType::FontFile;
@@ -49,7 +49,7 @@ BEGIN {
 
     @ISA = qw( PDF::API2::Basic::PDF::Dict );
 
-    ( $VERSION ) = '$Revision: 1.4 $' =~ /Revision: (\S+)\s/; # $Date: 2004/04/20 09:46:25 $
+    ( $VERSION ) = '$Revision: 1.5 $' =~ /Revision: (\S+)\s/; # $Date: 2004/06/07 19:44:43 $
 
 }
 
@@ -241,6 +241,9 @@ alfred reibenschuh
 =head1 HISTORY
 
     $Log: FontFile.pm,v $
+    Revision 1.5  2004/06/07 19:44:43  fredo
+    cleaned out cr+lf for lf
+
     Revision 1.4  2004/04/20 09:46:25  fredo
     added glyph->read fix for subset-vector
 
