@@ -27,7 +27,7 @@
 #   Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 #   Boston, MA 02111-1307, USA.
 #
-#   $Id: Font.pm,v 1.5 2004/05/21 15:10:29 fredo Exp $
+#   $Id: Font.pm,v 1.6 2004/06/07 19:44:36 fredo Exp $
 #
 #=======================================================================
 package PDF::API2::Resource::Font;
@@ -47,7 +47,7 @@ BEGIN {
 
     @ISA = qw( PDF::API2::Resource::BaseFont );
 
-    ( $VERSION ) = '$Revision: 1.5 $' =~ /Revision: (\S+)\s/; # $Date: 2004/05/21 15:10:29 $
+    ( $VERSION ) = '$Revision: 1.6 $' =~ /Revision: (\S+)\s/; # $Date: 2004/06/07 19:44:36 $
 
 }
 
@@ -203,6 +203,9 @@ alfred reibenschuh
 =head1 HISTORY
 
     $Log: Font.pm,v $
+    Revision 1.6  2004/06/07 19:44:36  fredo
+    cleaned out cr+lf for lf
+
     Revision 1.5  2004/05/21 15:10:29  fredo
     worked around some unicode probs
 
