@@ -27,7 +27,7 @@
 #   Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 #   Boston, MA 02111-1307, USA.
 #
-#   $Id: ean13.pm,v 1.4 2003/12/08 13:06:10 Administrator Exp $
+#   $Id: ean13.pm,v 1.5 2004/06/07 19:44:44 fredo Exp $
 #
 #=======================================================================
 
@@ -46,7 +46,7 @@ BEGIN {
 
     @ISA = qw( PDF::API2::Resource::XObject::Form::BarCode );
 
-    ( $VERSION ) = '$Revision: 1.4 $' =~ /Revision: (\S+)\s/; # $Date: 2003/12/08 13:06:10 $
+    ( $VERSION ) = '$Revision: 1.5 $' =~ /Revision: (\S+)\s/; # $Date: 2004/06/07 19:44:44 $
 
 }
 
@@ -181,6 +181,9 @@ alfred reibenschuh
 =head1 HISTORY
 
     $Log: ean13.pm,v $
+    Revision 1.5  2004/06/07 19:44:44  fredo
+    cleaned out cr+lf for lf
+
     Revision 1.4  2003/12/08 13:06:10  Administrator
     corrected to proper licencing statement
 
